@@ -43,11 +43,11 @@ How to use it:
 
         >>> python main.py --function predict --data_source 'csv' --csv_full_path 'test_data/daily-minimum-temperatures.csv' --predicted_column 1
 
-For more informations and some use cases check predictit readme or official docs. at
+For more informations and some use cases check predictit readme or official docs on
 
     https://predictit.readthedocs.io
 
-Feel free to contribute at
+Feel free to contribute on
 
     https://github.com/Malachov/predictit
 
@@ -68,13 +68,15 @@ from . import misc
 from . import plot
 from . import test_data
 from . import main_loop
+from . import gui_start
 
 from . import main
 
 
-__version__ = "1.36"
+__version__ = "1.37"
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
 __email__ = "malachovd@seznam.cz"
 
-__all__ = ['analyze', 'best_params', 'configuration', 'data_preprocessing', 'database', 'define_inputs', 'evaluate_predictions', 'main', 'misc', 'models', 'plot', 'test_data', 'main_loop']
+__all__ = ['analyze', 'best_params', 'configuration', 'data_preprocessing', 'database', 'define_inputs',
+           'evaluate_predictions', 'main', 'misc', 'models', 'plot', 'test_data', 'main_loop', 'gui_start']
