@@ -20,8 +20,17 @@ Examples:
     >>>     }
     >>> }
 
+    >>> # You can alse use this syntax
+    >>> config.datalength = 2000
+
+    >>> # Config work for predict() function as well as for predict_multiple_columns() and compare_models
+
     >>> predictions = predictit.main.predict()
 
+    >>> # You can pass configuration as dict kwargs...
+    >>> predictions = predictit.main.predict({})
+
+    >>> You can also apply config
 To see all the possible values, use
 
     >>> predictit.configuration.print_config()
@@ -44,22 +53,21 @@ class config():
     data = None  # Use numpy array, or pandas dataframe. This will overwrite data_source. If you use csv, set up to None. Data shape is (n_samples, n_feature). Rows are samples and columns are features.
     data_all = None  # [np.array(range(1000)), np.array(range(500))]  # Just for compare_models function. Dictionary of data names and list of it's values and predicted columns or list of data parts.
     # data_allexample = {data_1 = (my_dataframe, 'column_name_or_index')} or (my_data[-2000:], my_data[-1000:]) and 'predicted_column' as usually in config.
-    compare_mode = 'train_everytime'  # Some models have to be retrained to have predictions different from original data. Repeatit is just 1, so there have to be more member in data_all to reduce chance
 
     data_source = 'test'  # Data source. ('csv', 'txt', 'sql' or 'test') - If sql, you have to edit the query to fit your database.
 
-    csv_full_path = r'https://www.stats.govt.nz/assets/Uploads/Effects-of-COVID-19-on-trade/Effects-of-COVID-19-on-trade-1-February-1-July-2020-provisional/Download-data/Effects-of-COVID-19-on-trade-1-February-1-July-2020-provisional.csv'  # Full CSV path with suffix or web url. Examples: "https://raw.githubusercontent.com/jbrownlee/Datasets/master/daily-min-temperatures.csv" or "/home/dan/ownCloud/Github/predictit_library/predictit/test_data/daily-minimum-temperatures.csv"
+    csv_full_path = r''  # Full CSV path with suffix or web url. Examples: "https://raw.githubusercontent.com/jbrownlee/Datasets/master/daily-min-temperatures.csv" or "/home/dan/ownCloud/Github/predictit_library/predictit/test_data/daily-minimum-temperatures.csv"
     csv_test_data_relative_path = ''  # CSV name with suffix in test_data folder (E.g. '5000 Sales Records.csv' or 'daily-minimum-temperatures.csv' - !!! gitignored because of size. Download own.)
     # !!! Turn it off if not testing to not break csv full path !!! Test data are gitignored... use your own.
 
     predicted_column = ''  # Name of predicted column (for dataframe data) or it's index - string or int.
-    predicted_columns = []  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use '*' to predict all the columns with numbers.
+    predicted_columns = []  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use ['*'] to predict all the columns with numbers.
 
     freq = 0  # Interval for predictions 'M' - months, 'D' - Days, 'H' - Hours.
     freqs = []  # For predict_multiple function only! List of intervals of predictions 'M' - months, 'D' - Days, 'H' - Hours. Default use [].
     resample_function = 'sum'  # 'sum' or 'mean' depends of data. For example if current in technological process - mean, if units sold, then sum.
 
-    datetime_index = 'Date'  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
+    datetime_index = ''  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
 
     datalength = 0  # The length of the data used for prediction (after resampling). If 0, than full length.
     max_imported_length = 0  # Max length of imported samples (before resampling). If 0, than full length.
@@ -68,14 +76,11 @@ class config():
 
     predicts = 7  # Number of predicted values - 7 by default.
 
-    mode = 'predict'  # If 'validate', put apart last few ('predicts' + 'validation_gap') values and evaluate on test data that was not in train set. Do not setup - use compare_models function, it will use it automattically.
-    validation_gap = 10  # If 'mode' == 'validate', then describe how many samples are between train and test set. The bigger gap is, the bigger knowledge generalization is necesssary.
-
     return_type = 'best'  # 'best', 'all', 'dict', 'models_error_criterion', 'results_dataframe' or 'detailed_results_dictionary'.
     # 'best' return array of predictions, 'all' return more models
     # results sorted by how efficient they are. 'results_dataframe' return results and models names in columns. 'detailed_results_dictionary' is used for GUI
     # and return results as best result, all results, string div with plot and more. 'dict' return models dictionary with al the results. 'models_error_criterion' returns MAPE,
-    # RMSE (based on config) or dynamic warping criterion of all models in array.
+    # RMSE or DWT(based on config) criterion of all models in array.
 
     debug = 1  # Debug - If 1, print all results and all the warnings and errors on the way, if 2, stop on first warning, if -1 do not print anything, just return result.
 
@@ -136,6 +141,9 @@ class config():
     already_trained = 0  # Computationaly hard models (LSTM) load from disk.
     #plotallmodels = 0,  # Plot all models (recommended only in interactive jupyter window).
 
+    mode = 'predict'  # If 'validate', put apart last few ('predicts' + 'validation_gap') values and evaluate on test data that was not in train set. Do not setup - use compare_models function, it will use it automattically.
+    validation_gap = 10  # If 'mode' == 'validate' (in compare_models funciton), then describe how many samples are between train and test set. The bigger gap is, the bigger knowledge generalization is necesssary.
+
 
     #################################
     ### Models, that will be used ###
@@ -154,7 +162,8 @@ class config():
     used_models = {
 
         **{model_name: predictit.models.statsmodels_autoregressive for model_name in [
-            'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg', 'SARIMAX (Seasonal ARIMA)'
+            'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg',
+            'SARIMAX (Seasonal ARIMA)'
         ]},
 
         **{model_name: predictit.models.autoreg_LNU for model_name in [
@@ -162,13 +171,16 @@ class config():
 
         'Conjugate gradient': predictit.models.conjugate_gradient,
 
-        # # # 'tensorflow_lstm': predictit.models.tensorflow,
-        # # # 'tensorflow_mlp': predictit.models.tensorflow,
+        ### 'tensorflow_lstm': predictit.models.tensorflow,
+        ### 'tensorflow_mlp': predictit.models.tensorflow,
 
         **{model_name: predictit.models.sklearn_regression for model_name in [
             'Sklearn regression', 'Bayes ridge regression', 'Passive aggressive regression', 'Gradient boosting',
             'KNeighbors regression', 'Decision tree regression', 'Hubber regression',
             # 'Bagging regression', 'Stochastic gradient regression', 'Extreme learning machine', 'Gen Extreme learning machine',  'Extra trees regression', 'Random forest regression'
+
+            'Sklearn regression one step', 'Bayes ridge regression one step', 'Decision tree regression one step',
+            'Hubber regression one step',
         ]},
 
         'Compare with average': predictit.models.compare_with_average
@@ -201,18 +213,25 @@ class config():
     models_input = {
 
         **{model_name: 'data_one_column' for model_name in [
-            'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg', 'SARIMAX (Seasonal ARIMA)']},
+            'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg',
+            'SARIMAX (Seasonal ARIMA)']},
 
         **{model_name: 'one_in_one_out_constant' for model_name in [
-            'Autoregressive Linear neural unit', 'Autoregressive Linear neural unit normalized', 'Linear neural unit with weigths predict', 'Conjugate gradient']},
+            'Autoregressive Linear neural unit', 'Autoregressive Linear neural unit normalized',
+            'Linear neural unit with weigths predict', 'Conjugate gradient']},
 
         **{model_name: 'batch' for model_name in [
-            'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Extra trees regression', 'Decision tree regression', 'KNeighbors regression', 'Random forest regression',
-            'Bagging regression', 'Passive aggressive regression', 'Extreme learning machine', 'Gen Extreme learning machine', 'Gradient boosting']},
+            'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Extra trees regression',
+            'Decision tree regression', 'KNeighbors regression', 'Random forest regression',
+            'Bagging regression', 'Passive aggressive regression', 'Extreme learning machine',
+            'Gen Extreme learning machine', 'Gradient boosting']},
+
+        **{model_name: 'one_step' for model_name in [
+            'tensorflow_mlp', 'Sklearn regression one step', 'Bayes ridge regression one step',
+            'Decision tree regression one step', 'Hubber regression one step']},
 
         'Stochastic gradient regression': 'one_in_batch_out',
         'tensorflow_lstm': 'not_serialized',
-        'tensorflow_mlp': 'one_step',
 
         'Compare with average': 'data_one_column'
     }
@@ -232,11 +251,11 @@ class config():
         'Linear neural unit with weigths predict': {'mi_multiple': 1, 'mi_linspace': (1e-5, 1e-4, 3), 'epochs': 10, 'w_predict': 1, 'minormit': 0},
         'Conjugate gradient': {'epochs': 200},
 
-        'tensorflow_lstm': {'layers': 'default', 'epochs': 200, 'already_trained': 0, 'save': 1, 'saved_model_path_string': 'stored_models', 'optimizer': 'adam', 'loss': 'mse', 'verbose': 0, 'metrics': 'accuracy', 'timedistributed': 0},
+        'tensorflow_lstm': {'layers': 'default', 'epochs': 200, 'load_trained_model': 0, 'update_trained_model': 0, 'save_model': 1, 'saved_model_path_string': 'stored_models', 'optimizer': 'adam', 'loss': 'mse', 'verbose': 0, 'metrics': 'accuracy', 'timedistributed': 0},
         'tensorflow_mlp': {'layers': [['dense', {'units': 32, 'activation': 'relu'}],
                                       ['dropout', {'rate': 0.1}],
                                       ['dense', {'units': 7, 'activation': 'relu'}]],
-                           'epochs': 100, 'already_trained': 0, 'save': 1, 'saved_model_path_string': 'stored_models', 'optimizer': 'adam', 'loss': 'mse', 'verbose': 0, 'metrics': 'accuracy', 'timedistributed': 0},
+                           'epochs': 100, 'load_trained_model': 0, 'update_trained_model': 0, 'save_model': 1, 'saved_model_path_string': 'stored_models', 'optimizer': 'adam', 'loss': 'mse', 'verbose': 0, 'metrics': 'accuracy', 'timedistributed': 0},
 
         'Sklearn regression': {'regressor': 'linear', 'alpha': 0.0001, 'n_iter': 100, 'epsilon': 1.35, 'alphas': [0.1, 0.5, 1], 'gcv_mode': 'auto', 'solver': 'auto', 'alpha_1': 1.e-6,
                                'alpha_2': 1.e-6, 'lambda_1': 1.e-6, 'lambda_2': 1.e-6, 'n_hidden': 20, 'rbf_width': 0, 'activation_func': 'selu'},
@@ -249,6 +268,11 @@ class config():
         'Bagging regression': {'regressor': 'Bagging'},
         'Stochastic gradient regression': {'regressor': 'Stochastic gradient'},
 
+        'Sklearn regression one step': {'regressor': 'linear'},
+        'Bayes ridge regression one step': {'regressor': 'bayesianridge'},
+        'Decision tree regression one step': {'regressor': 'Decision tree'},
+        'Hubber regression one step': {'regressor': 'huber'},
+
         'Extreme learning machine': {'regressor': 'elm', 'n_hidden': 50, 'alpha': 0.3, 'rbf_width': 0, 'activation_func': 'tanh'},
         'Gen Extreme learning machine': {'regressor': 'elm_gen', 'alpha': 0.5}
     }
