@@ -50,7 +50,7 @@ def load_data(config):
         data = predictit.test_data.generate_test_data.gen_random()
         user_warning(("Test data was used. Setup config.py 'data_source'. Check official readme or do"
                       " >>> predictit.configuration.print_config() to see all possible options with comments. "
-                      "Data can be insert as function parameters, with editing config.py or with CLI."))
+                      "Data can be also inserted as function parameters, with editing config.py or with CLI."))
 
     return data
 
