@@ -9,10 +9,20 @@ import traceback
 
 # If some information from inside main(), define function here
 def edit_gui_py(content, id):
+    """Function that will change some element in html GUI and is callable from other py scripts.
+
+    Args:
+        content (str): New content.
+        id (str): Id of changed element.
+    """
+
     eel.edit_gui_js(content, id)
 
 
 def run_gui():
+    """Start web based GUI.
+    """
+
     web_path = str(Path(__file__).resolve().parents[0] / "files_for_GUI")
 
     eel.init(web_path)
@@ -37,9 +47,15 @@ def run_gui():
         "csv_test_data_relative_path": "",
     })
 
+    # Functions with @eel prefix are usually called from main.js file.
+
     @eel.expose
     def make_predictions(configured):
+        """Function that from web GUI button trigger the predictit main predict function and return results on GUI.
 
+        Args:
+            configured (dict): Some configuration values can be configured in GUI.
+        """
         for i, j in configured.items():
             if j != "" and i in config:
 
@@ -85,7 +101,6 @@ def run_gui():
         except Exception:
 
             eel.add_HTML_element(f"\n Error in making predictions - {predictit.misc.remove_ansi(traceback.format_exc())} \n", True, "progress_phase", "error-log", "Error log", "pre-wrapped")
-            #eel.edit_gui_js(f"\n Error in making predictions - {traceback.format_exc()} \n", "progress_phase")
 
     eel.start('index.html', port=0)  # mode='chrome-app'
 
